@@ -29,15 +29,14 @@ def simulator(params, logger):
     simu_args.repeat = 1
     simu_args.handle_symptomatic = 'remove'
 
-    return Simulator(params=params, logger=logger, simu_args=simu_args)
+    return Simulator(params=params, logger=logger, simu_args=simu_args, cmd=[])
 
 
 @pytest.fixture
 def individual(default_model, logger):
-    return Individual(0, 'group', 0.8, None, None, default_model, logger)
+    return Individual('0', 'group', 0.8, default_model, logger)
 
 
 @pytest.fixture
 def individual_factory(default_model, logger):
-    return lambda id: Individual(id, 'group 2', 1.2, None, None, default_model,
-                                 logger)
+    return lambda id: Individual(id, 'group 2', 1.2, default_model, logger)
