@@ -117,12 +117,41 @@ def test_plugin_sample_error():
         ])
 
 
-def test_plugin_dynamic_r0():
+def test_plugin_setparam():
     main([
-        '--jobs', '1', '--repeats', '100', '--plugin', 'dynamic_r0', '--at',
-        '1', '--new-symptomatic-r0', '0.2'
+        '--jobs', '1', '--repeats', '100', '--plugin', 'setparam', '--at', '1',
+        '--symptomatic-r0', '0.2'
     ])
     main([
-        '--jobs', '1', '--repeats', '100', '--plugin', 'dynamic_r0', '--at',
-        '1', '--new-asymptomatic-r0', '0.4'
+        '--jobs', '1', '--repeats', '100', '--plugin', 'setparam', '--at', '1',
+        '--asymptomatic-r0', '0.4'
+    ])
+
+
+def test_plugin_insert():
+    main([
+        '--jobs', '1', '--repeats', '100', '--stop-if', 't>10', '--plugin',
+        'insert', '2', '--at', '1'
+    ])
+    main([
+        '--jobs', '1', '--repeats', '100', '--stop-if', 't>10', '--plugin',
+        'insert', '2', '--interval', '1'
+    ])
+
+
+def test_plugin_insert_hetero_pop():
+    main([
+        '--jobs', '1', '--repeats', '100', '--stop-if', 't>10', '--popsize',
+        'A=100', 'B=100', '--stop-if', 't>10', '--plugin', 'insert', 'A=2',
+        '--interval', '1'
+    ])
+
+
+def test_plugin_pcrtest():
+    main(['--jobs', '1', '--repeats', '100', '--plugin', 'pcrtest'])
+    main(['--jobs', '1', '--repeats', '100', '--plugin', 'pcrtest', '1', '2'])
+    main([
+        '--jobs', '1', '--repeats', '100', '--popsize', 'A=100', 'B=200',
+        '--infector', 'A2', 'A7', '--plugin', 'pcrtest', 'A2', 'A7',
+        '--handle-positive', 'quarantine_7'
     ])
